#
# spec file for package python-ciscoconfparse
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-ciscoconfparse
Version:        1.7.18
Release:        1.3
Summary:        Library for parsing, querying and modifying Cisco IOS-style configurations
License:        GPL-3.0-or-later
URL:            https://github.com/mpenning/ciscoconfparse
Source:         https://files.pythonhosted.org/packages/source/c/ciscoconfparse/ciscoconfparse-%{version}.tar.gz
BuildRequires:  %{python_module dnspython >= 2.1.0}
BuildRequires:  %{python_module loguru >= 0.6.0}
BuildRequires:  %{python_module passlib >= 1.7.4}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module toml >= 0.10.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with python2}
BuildRequires:  python2-ipaddr >= 2.1.11
BuildRequires:  python2-mock
%endif
Requires:       python-dnspython >= 2.1.0
Requires:       python-loguru >= 0.6.0
Requires:       python-toml >= 0.10.2
%ifpython2
Requires:       python-ipaddr >= 2.1.11
%endif
BuildArch:      noarch
%python_subpackages

%description
ciscoconfparse is a Python library, which parses through Cisco IOS-style
(and other vendor) configurations.  It can:

- Audit existing router / switch / firewall / wlc configurations
- Retrieve portions of the configuration
- Modify existing configurations
- Build new configurations

The library examines an IOS-style config and breaks it into a set of linked
parent / child relationships.  You can perform complex queries about these
relationships.

%prep
%autosetup -p1 -n ciscoconfparse-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# no online dns (and /etc/resolv.conf) available
#%%pytest -k "not (test_dns_lookup or test_reverse_dns_lookup)"

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/ciscoconfparse
%{python_sitelib}/ciscoconfparse-%{version}-py%{python_version}.egg-info

%changelog
* Wed Apr 19 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.18:
  * Streamline the `ConfigLineFactory()` function
  * Replace four `_bootstrap_obj_init_FOO()` methods where FOO is
    {ios, nxos, asa, junos}.  The repalcement is
    `_bootstrap_obj_init_ng()`, which handles initial parse from
    text into `*CfgLine()` object instances for *all* syntax.
  * Rename `_build_cfgobj_from_text()` to `_cfgobj_from_text()`
  * Deprecate `ConfigList()._bootstrap_from_text()` and replace
    it with `ConfigList()._bootstrap_obj_init_ng()`
  * Remove `foo_DEPRECATED()` code in
    `ciscoconfparse/ciscoconfparse.py`
  * Modify `CiscoConfParse()` to parse `syntax='ios'` roughly 25%%
    faster.
  * Simplify `find_object_branches()`
  * Remove unused test fixtures and imports
  * As part of Github issue #264 (Remove duplicated obj init code
    from `CiscoConfParse()._bootstrap_obj_init_foo()`), also
    remove a duplicate method:
    `ConfigList()._build_cfgobj_from_text()`
  * As part of Github issue #265, fix a broken `loguru`
    parameter: change it from `allow_enqueue` to `enqueue`
  * Close Github issue #266 as wont-fix: make
    `BaseCfgLine().calculate_line_id()` hash comments /
    whitespace
  * Reformat `ciscoconfparse/ciscoconfparse.py` and
    `ciscoconfparse/ccp_abc.py` with black
  * Add new `as_dict_diff` attribute (used by `HDiff()`) on
    `BaseCfgLine()`.
  * Add more debugs in `HDiff().compress_dict_diffs()`.
  * Raise an explicit `NotImplementedError` in
    `HDiff().sort_lines()`
  * Remove manual prepends from `HDiff()` and
    `CiscoConfParse().sync_diff()`
  * Remove hard-coded blank-line handling which was based on the
    value of the `HDiff()` `syntax` parameter
  * Add `ignore_blank_lines` parameter to `HDiff()` (to mirror
    the same parameter in `CiscoConfParse()`)
  * Remove the `consider_whitespace` parameter from
    `HDiff().build_diff_obj_list()`
  * Change `CiscoConfParse()._list` to
    `CiscoConfParse().ConfigObjs`
  * Expand test coverage to test parsing with and without blank
    lines in the input config.
  * Add more test cases to check blank line parsing while using
    any valid ccp syntax
  * Update documentation
  * Summary:
  * Add initial support for `CiscoConfParse()` object instance
    support in `HDiff()`
  * Add `HDiff()` documentation
  * Convert `diff_word` and `diff_side` `HDiff()` attributes to
    `HDiff()` getter / setter methods
  * Improve `BaseCfgLine()` initialization
  * Improve `BaseCfgLine()` attribute handling: `.text`,
    `.indent`
  * Remove loop in `testValues_find_children()` to simplify test
    flow.
  * Ensured that all comments are their own parents - comments
    can NOT be children of a parent
  * Add `ccp_util.fix_repeated_words()`
  * Change `allow_enqueue` parameter to `enqueue` in
    `ccp_logger_control()`.  `allow_enqueue` is not a valid
    `loguru` parameter name.
  * ## Version: 1.7.15
  * Released: 2023-02-10
  * Summary:
  * Streamline `_bootstrap_from_text()` code.
  * Extract common code into `_build_banner_re_ios()` (for nxos
    and ios)
  * Extract common object init code from
    `CiscoConfParse()._bootstrap_obj_init_foo()` (where foo =
    asa, ios, nxos and junos) into `_build_cfgobj_from_text()`.
  * Remove the unused `output_format` parameter from `HDiff()`
  * Add `HDiff()` docstrings
  * Resolved Github issue #262: bad function argument + infinite
    recursion problem
  * Resolved Github issue #263: Remove duplicated code from
    `CiscoConfParse()._bootstrap_from_text()`
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.14:
  * Allow `CiscoConfParse()` to parse an empty
    configuration command list i.e. `CiscoConfParse([])`; remove
    the `ValueError()` raised on parsing an empty config.
  * Re-implement and simplify
    `CiscoConfParse().sync_diff()` with `HDiff()`.
  * Rename variables in `HDiff().compress_dict_diffs()`.
  * Rename dict_line to line and add the command indent
  * Add 'parents' to `HDiff()` diff dicts and add parent
    line output in `sync_diff()`
  * Expand `CiscoConfParse()` test coverage for reading
    files from disk
  * Fix `CiscoConfParse().read_config_file()` recursive
    call in `read_config_file()`.
  * Fix `CiscoConfParse().read_config_file()` missing
    `open()` in `read_config_file()`.
  * Fix file-open test escapes associated with github issue
  * Fix `CiscoConfParse().read_config_file()` argument name
    test escape (ref github issue #262)
  * Improve file `open()` error handling.  NOTE:
    `FileNotFoundError()` is now raised for invalid file paths.
  * Improve edge case handling for Cisco IOS banner
    delimiters.
  * Remove `_validate_ConfigObjs()` and improve logic in
    `CiscoConfParse().__init__()`.
  * Revert back to using `read_config_file()` if the config
    is stored in a file.
  * Fix unit tests to work with version 1.7.8+
  * Streamline `CiscoConfParse().__init__()` logic and
    delegate `__init__()` tasks to dedicated methods.
  * Validate that `CiscoConfParse().ConfigObjs` is None or
    instance of `collections.abc.Sequence()`
  * Convert all checks for `collections.abc.Iterator` to
    `collections.abc.Sequence`; ref github issue #256
  * Add more error conditions and explicit errors in
    ciscoconfparse/ciscoconfparse.py
  * Implement `read_config_file()` logic
  * Add more unit tests
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.7:
  - Replace `assert isinstance()`, as requested in github issue #256
  - Remove test `ping` code from `Makefile`
  - Small code reorganization in `class CiscoConfParse()`
  - Move non-essential packages to requirements-dev.txt (github issue #258)
  - Edit in documentation style fixes recommended by `pydocstyle -e --convention=numpy <filename>`.
  - Convert some of the assertions that validated `CiscoConfParse()` method
    parameters and variables into if-statements for more idiomatic python.
  - Convert some of the clunky-python-syntax into more idiomatic python.
  - Rip out all `terraform` parsing attempts.
  - Update for CVE-2022-40898 in the python `wheel <= 0.38.0` package.
  - github issue #257 reported this issue.
  - Modified `requirements.txt` to manually upgrade `python`'s default `wheel` version to a patched version of `wheel`.
  - Move documentation package dependencies to `sphinx-doc/requirements.txt`
  - Add documentation build instructions to `README.md`
* Wed Jan 18 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.1:
  * Improve config parsing code
  * Make ConfigList() more stable
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * Add deprecat dependency
  * Add more Makefile targets
  * Makefile will successfully ping to internet or fail
  * Update Makefile to delete poetry.lock file
  * Correct 'make ping' logic and other tricky Makefile syntax
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.6.53
  Released: 2022-11-18
  Summary:
  * Reformat pyproject.toml to be most compatible with 'pip install'
  * Several internal project-level optimizations...
  * git changes committed on 2022-11-09... somehow 1.6.53 wasn't pushed to pypi on 9-Nov-2022. It was pushed to pypi on 18-Nov-2022
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.6.52
  Released: 2022-11-09
  Summary:
  * Fix Github Issue #254
- Update to version: 1.6.51
  Released: 2022-10-21
  Summary:
  * Add user and project parameters to dev_tools/git_helper.py.
    Modify the Makefile accordingly
  * Fix .delete(recurse=True) implementation (see Github Issue #253)
  * Fix incorrect debug level check in _bootstrap_from_text()
  * Add more debug logs... however, many methods still lack debug messages
* Thu Oct 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.6.50:
  Released: 2022-10-21
  Summary:
  * Modify .github/workflows/tests.yml with improved yml
  * Enhance CiscoConfParse().repr() string output
  * Minor package documentation tweaks
- Update to version 1.6.49:
  * Adjust string strip() conditions on config lines in assign_parent_to_closing_braces()
- Update to version 1.6.48:
  * Add code to catch misconfigurations such as parsing a string instead of a list in ciscoconfparse.ConfigList(``)
  * Avoid problems with reading empty lines (see Github Issue #251)
- Update to version 1.6.47:
  * Add repo version management into the Makefile ('make bump-version-patch' / 'make bump-version-minor')
  * Add repo version management to 'dev_tools/git_helper.py'
  * Revise README_git_workflow.md to include more rebase and merge details
* Fri Oct 21 2022 Markéta Machová <mmachova@suse.com>
- Add missing runtime requirement
* Tue Oct  4 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.41
  * Modify `uncfgtext`.  Deprecate `add_uncfgtext()`
  * Add a dedicated bootstrap method (`_bootstrap_obj_init_junos()`)
    for parsing `syntax==junos`
  * Add `JunosCfgLine()`
  * Remove `NXOSConfigList()` and `ASAConfigList()`
  * Add test coverage for "parsing F5 configs as ios", "parsing F5
    configs as junos"
  * Add config diff infrastructure (preparing to make heavy changes
    to diffs)
  * Fix problems with `ip_factory()`
  * Add `_ip` property to `IPv4Obj()` and `IPv6Obj()`
  * Add support for IPv4 Mapped IPv6 Addresses
  * Fix `BaseCfgLine().has_child_with()` method
  * Make `ip_factory()` more resilient
  * Code cleanup
  * Fix IPv6 bug in `ip_factory()`
  * Enhance `regex_groups` on `find_object_branches`
  * Add regex match group support to `find_object_branches`
  * Ensure masklen and prefix are int objects for `IPv4Obj()` and
    `IPv6Obj()` network mask length
  * Add `ccp_util.ip_factory()`
  * Added a "disable" and "enable" command to `ccp_logger_control()`
  * Add `ccp_logger_control()`
  * Fix race-condition for `CiscoConfParse` kwarg in
    `IOSConfigList`, `NXOSConfigList`, and `ASAConfigList`
  * Add explicit configuration file encoding with default encoding
    from python's locale module
  * Remove colorama dependency.
- Drop patch:
  * no2to3.patch (not longer needed)
- Temporary disable tests since they are not longer part of the
  pypi-tarball.
* Tue Mar  1 2022 Dirk Müller <dmueller@suse.com>
- add no2to3.patch for compatibility with newer setuptools
* Tue Nov  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.60
  * Fix race-condition for `CiscoConfParse` kwarg in IOSConfigList,
    NXOSConfigList, and ASAConfigList.
  * Add explicit configuration file encoding with default encoding
    from python's locale module.
  * Add tests to catch breakage similar to Github Issue #209.
  * Remove colorama dependency.
* Tue Nov  2 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.51
  * New release with modified copyrights
  * Fix typos and syntax
  * Fix insert_before() and insert_after(), update Copyrights
  * Expose a proxy function to call ipaddress.collapse_addresses()
  * More logging work... prepare for debugging overhaul.
  * Refine error logging in setup.py
  * Fix get_metadata() returned value in setup.py
  * Rework version.json to metadata.json
* Tue Jul 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.36
  * Fix git tags in Makefile
  * Add a helper-function: as_text_list(); improve performance of
    .delete()
  * Fix __int__() and __index__() on IPv4Obj() and IPv6Obj()
  * Enhance ccp_util.CiscoRange() to parse a wider variety of
    string inputs
  * Remove slow code from ccp_util.CiscoRange()
  * Make ccp_util.L4Object().__repr__() more friendly
* Sat Jan 23 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.5.25
  * Fix Github Issue gh#mpenning/ciscoconfparse#195
  * merge PR gh#mpenning/ciscoconfparse#194
  * fix multiple unreported bugs in ccp_util.L4Object()
- Drop remove-mock.patch and test-lists.patch fixed upstream
* Fri Jan 22 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 1.5.24
  * Fix Github Issue #178
- Changes for 1.5.23
  * Prevent find_object_branches() from using None
- Changes for 1.5.22
  * Fix Github issue #186 (replace variables named input)
- Changes for 1.5.21
  * Fix Github issue #187
- Changes for 1.5.20
  * Fix Github issue #185
- Changes for 1.5.19
  * Add __ne__() support to IPv4Obj and IPv6Obj
- Changes for 1.5.18
  * Fix Github issue #180 - IPv4Obj() and IPv6Obj() cannot
    use logical compare ops with certain Python objects
- Changes for 1.5.17
  * Fix Python 2.7 packaging
- Changes for 1.5.7
  * Revise IPv4Obj & IPv6Obj __lt__(), __gt__(), and
    __contains__() methods (impacts sorting behavior);
    reformatted documentation to latest numpydoc format.
    Add version number as json data instead of raw text...
- Add remove-mock.patch -- gh#mpenning/ciscoconfparse#194
- Add test-lists.patch -- gh#mpenning/ciscoconfparse#195
* Sun Jun 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.6
  * Improve find_object_branches() speed
* Sat Jun 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.5
  * Beta-test new function: find_object_branches()
- Update to version 1.5.4
  * Modify IPv4Obj().__add__() and IPv6Obj().__add__() (and __sub__())
    methods return IPv4Obj()/IPv6Obj() objects.
  * Add support for int(), bin() and hex() on the IPv4Obj() and IPv6Obj()
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Sun Apr 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.3
  * Fix IPv6Obj().packed and IPv6Obj().exploded
  * add IPv4Obj().packed and IPv4Obj().exploded
- Update to version 1.5.2
  * Add __add__() and __sub__() to IPv4Obj() and IPv6Obj();
  * remove use of IPv6Obj().broadcast in IPv6Obj().__contains__()
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.1
  * Remove embedded junos debugging
- Update to version 1.5.0
  * Complete rewrite of junos parser (fix Github issue #70)
  * deprecate support for Python 3.4
* Thu Dec  5 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.11
  * Explicitly close() open filehandles
* Mon Nov 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.10
  * Add support for parsing pathlib.Path objects which contain a
    configuration
* Fri Nov 22 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.9
  * Add .as_cidr_net and .as_cidr_addr on IPv4Obj and IPv6Obj
  * Merge Github PR #168; rename in_portchannel and is_portchannel
* Thu Sep 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.7:
  * various small fixes
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.5:
  * distribute tests
  * various fixes
* Thu Aug  1 2019 pgajdos@suse.com
- version update to 1.4.1
  * Fix Github issue #141; NOTE - This will break parsing helper-addresses under factory=True.  If you use this feature, please migrate your scripts to the new format
  * Implement re_search_children() directly on the CiscoConfParse() object
  * Fix Github issue #158, *KEYWORD CHANGE WARNING:* some methods formrely used a keyword called 'all_children'.  The new syntax is 'recurse' (ref: Github issue #159)
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.32:
  * No good changelog
- Remove unused patch ciscoconfparse-1.2.40-fix-tests.patch
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.30:
  * Fix bugs related to Python3 (Github issue #117)
  * Add IP helper-address parsing in models_cisco.py
  * Revert universal wheel packages (universal=0)
  * Build universal wheel packages
  * Build improvements - ref Github issue #127, #128
  * Another swing at Github issue #127
  * Rollback fix for Github issue #127
  * Attempt to fix Github issue #127
  * Fix Github issue #124-126 and Github issue #110
  * Fix Github issue #121 and Github issue #123
  * Fix Github issue #114 (Py3.5 requires different open() syntax)
  * Fix Github issue #111 (banner parsing broken in some cases)
  * Add * to MANIFEST.in
  * Attempt to resolve Github issue #106
  * Add dns_query() zone transfer as text
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary.
* Tue May 22 2018 mcepl@suse.com
- Uprgade to version 1.3.15
  * Many trivial bug fixes, see CHANGES
- Renamed skip-setuptools-hg-require.patch to
  ciscoconfparse-1.2.40-fix-tests.patch
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sun Oct  9 2016 mardnh@gmx.de
- Update to version 1.2.40
  * Fix Github issue #44 (Could not parse 'ipv6 router ospf 6').
  * Modify default value for access_vlan.
  * Add new is_portchannel property.
  * Update copyright dates.
  * Remove OSX from test matrix
- Fix source url
* Sun Mar 13 2016 dmueller@suse.com
- fix license
* Fri Feb  5 2016 tbechtold@suse.com
- Initial packaging (version 1.2.39)
